@@ -435,6 +435,50 @@ ReportNavigationView = KS.extend(BaseSvodView, {
             view.touch();
         },
 
+        budgetTreeCheckFromBeginToCurrent: function () {
+            var view = this.parentView;
+            var selNode = view.budgetTree.getSelNode();
+            var parentNode = selNode.parentNode;
+            var selIndex = parentNode.indexOf(selNode);
+            view.setCheckedChildNodesBetweenIndexes(parentNode, true, 0, selIndex);
+        },
+
+        budgetTreeCheckFromCurrentToEnd: function () {
+            var view = this.parentView;
+            var selNode = view.budgetTree.getSelNode();
+            var parentNode = selNode.parentNode;
+            var selIndex = parentNode.indexOf(selNode);
+            view.setCheckedChildNodesBetweenIndexes(parentNode, true, selIndex);
+        },
+
+        budgetTreeCheckBetweenMarked: function () {
+            var view = this.parentView;
+            var checkedNodes = view.budgetTree.getChecked();
+            var firstNode = checkedNodes[0];
+            var secondNode = checkedNodes[1];
+
+            if (firstNode.parentNode === secondNode.parentNode) {
+                var parentNode = firstNode.parentNode;
+                var idx1 = parentNode.indexOf(firstNode);
+                var idx2 = parentNode.indexOf(secondNode);
+                view.setCheckedChildNodesBetweenIndexes(parentNode, true, idx1, idx2);
+            }
+        },
+
+        setCheckedChildNodesBetweenIndexes: function (parentNode, checked, begin, end) {
+            if (!end) end = parentNode.childNodes.length - 1;
+
+            if (begin > end) return;
+
+            Ext.each(parentNode.childNodes, function (node) {
+                var currIdx = parentNode.indexOf(node);
+                if (currIdx >= begin && currIdx <= end)
+                    node.set('checked', checked);
+            });
+
+            this.touch();
+        },
+
         budgetNodeMenuClick: function(menuItem) {
             var view = this.parentView,
                 bsnId = view.budgetTree.getSelNodeId(),
