@@ -57,31 +57,19 @@
 
         printChart: function() {
             var view = this.parentView || this;
-            view.chart.download({
-//                url: KS.getServerUri(),
-                filename : "chart", // обращается к http://svg.sencha.io
-                format: "pdf",
-                pdf : {
-                    format: 'A4',
-                    orientation: 'landscape',
-                    border: '1cm'
-                }
-            });
+            var image = view.chart.getImage();
+            if (image){
+                var title = view.statsModeCombo.getDisplayValue(); // имя файла, если сохранять его в pdf
+                KS.Svod.ImageUtils.printFromBase64(image.data, title);
+            }
         },
 
         saveChartInFiles: function() {
             var view = this.parentView || this;
-            view.chart.download({
-//                url: KS.getServerUri(),
-                filename : "chart_image" // обращается к http://svg.sencha.io
-            });
-//            var chartImage = view.chart.getImage();
-//            var chartImageData = chartImage['data'];
-//            var chartImageFormat = chartImage['type'];
-//            view.serverCall({
-//                method: 'SaveChartInFiles',
-//                params: [chartImageData, chartImageFormat]
-//            });
+            var image = view.chart.getImage();
+            if (image){
+                KS.Svod.ImageUtils.downloadFromBase64(image.data, 'chart_image');
+            }
         },
 
         emailChartImage: function() {
